#!/bin/bash
# usbfathdd.sh - cbagger01's slightly modified version of
# the original pendrive_usbhdd.sh / pendrive_usbzip.sh by
# (c) Robert Shingledecker 2005

. /etc/init.d/dsl-functions

MIRROR=$(dslrc.lua Mirror) || MIRROR="ibiblio.org/pub/Linux/distributions/damnsmall/"
PROTOCOL=$(dslrc.lua Protocol) || PROTOCOL="http"
export PATH="$PATH:."

clear
echo
echo "${RED}DSL ${WHITE}pendrive BIOS boot FAT USB_HDD ${BLUE}install/update.${NORMAL}"
echo
echo "1. Your BIOS must support USB-HDD booting."
echo "2. A single FAT partition will be made."
echo "3. Backup/Restore will be pre setup."
echo "4. Do not have your pendrive mounted."
echo  
echo "${YELLOW}No responsibility for data loss or hardware damage!${NORMAL}"
echo

echo -n "${CYAN}Enter the device name of pendrive.${WHITE}(EXAMPLE: ${YELLOW}sda): ${NORMAL}" 
read DEVICE
if [ -z "$DEVICE" ] ; then
  echo "No device chosen. The script will be terminated."
  echo -n "Press Enter key to continue."; read gagme
  exit 1
fi    
TARGET="$DEVICE"1


INSTALLTYPE=""
until [ "$INSTALLTYPE" == "i" ] || [ "$INSTALLTYPE" == "u" ]; do
   echo -n "${CYAN}Is this an installation or upgrade? ${NORMAL}(i,u) "; read INSTALLTYPE
done

if [ ! -f bootfloppy-usb.img ]; then
   echo "${BLUE}Standby fetching the bootusb image file...${NORMAL}"
   wget -q "$PROTOCOL"://"$MIRROR"/current/bootfloppy-usb.img.md5.txt
   wget "$PROTOCOL"://"$MIRROR"/current/bootfloppy-usb.img
   if [ $? != 0 ]; then
      echo "${RED}Error while trying to fetch the bootusb image file.${NORMAL}"
      rm -f bootfloppy-usb.img
      echo "Script is terminating..."
      echo -n "Press Enter key to continue."; read gagme
      exit 1
   fi
    md5sum -c bootfloppy-usb.img.md5.txt
    if [ $? != 0 ]; then
      echo "${RED}Checksum error in downloaded file"
      echo "The script is terminating...${NORMAL}"
      echo -n "Press Enter key to continue."; read gagme
      exit 1
    fi
fi


echo -n "${CYAN}Use DSL iso from [L]iveCD, from [F]ile, from [W]eb. ${YELLOW}(l/f/w): ${NORMAL}"
read INSTALL
case "$INSTALL" in 
  "L" | "l")
    if [ -f /etc/sysconfig/toram ]; then
       echo "You are not running from LiveCD. Running 'toram' is not running live."
       echo -n "Script will be terminated. Press Enter key."; read gagme
       exit 1
    fi
    SOURCE="/cdrom"
    IMAGE="/cdrom"
  ;;   
  "F" | "f")
    # read path from user                                               
    echo -n "${CYAN}Enter the full path to the iso.  ${WHITE}(EXAMPLE: ${YELLOW}/home/dsl/dsl-1.0.1.iso): ${NORMAL}"
    read SOURCE
    if [ -z "$SOURCE" ] ; then
      echo "No path entered. The script will be terminated."
      exit 0
    fi          
  ;;  
  "W" | "w")
    # fetch ISO from web.
    echo "${BLUE}Standby fetching ISO.${NORMAL}"
    wget -q "$PROTOCOL"://"$MIRROR"/current/current.iso.md5.txt
    wget "$PROTOCOL"://"$MIRROR"/current/current.iso
    if [ $? != 0 ]; then
      rm -f current.iso
      echo "${RED}Sorry the iso image file could not be retrieved or does not fit"
      echo "on your ramdisk."
      echo "The script is terminating...${NORMAL}"
      exit 1
    fi
    md5sum -c current.iso.md5.txt
    if [ $? != 0 ]; then
      echo "${RED}Checksum error in downloaded file"
      echo "The script is terminating...${NORMAL}"
      exit 1
    fi

    SOURCE="current.iso"
  ;;  
esac  

if [ "$SOURCE" != "/cdrom" ]; then
  # We need to mount the ISO file using the loopback driver.
  # Start by creating a mount point directory; we'll call it "staging"
  mkdir /mnt/staging
  mount -t iso9660 -o loop,ro $SOURCE /mnt/staging
  if [ $? != 0 ]; then
    umount /mnt/pendrive  # unmount the target drive 
    echo "${RED}Sorry $SOURCE not found!"
    echo "Installation not successful!${NORMAL}"
    echo -n "Press Enter key to continue."; read gagme
    exit 1
  fi  
  IMAGE="/mnt/staging"
fi

echo "${CYAN}List boot options: "
echo -n "${WHITE}Example: ${YELLOW}vga=normal toram ssh nfs syslog lpd monkey ftp${NORMAL}: "
read DAEMONS

echo "${CYAN}Choose language/keyboard if other than english: "
echo -n "${WHITE}Example: ${YELLOW}cs da de es fr nl it pl ru sk${NORMAL}: "
read LANG
if [ ! -z "$LANG" ]; then
   LANG="lang=$LANG"
fi

RESTORE="restore=$TARGET";  MYDSL="mydsl=$TARGET"

echo -n "${RED}Ready to proceed.${NORMAL} (y/..)? "
read answer
if [ "$answer" != "y" ]; then
  echo "Aborted by user."
  echo "Press Enter key to continue: "; read gagme
  exit 1
fi
if [ "$INSTALLTYPE" == "i" ]; then
  echo
  echo "${RED}Last change to exit before destroying all data on ${MAGENTA}/dev/$DEVICE${NORMAL}"
  echo -n "${CYAN}Continue (y/..)?${NORMAL} "
  read answer
  if [ "$answer" != "y" ]; then
    echo "Aborted.."
    echo -n "Press Enter key to continue."; read gagme
    exit 0
  fi
  echo
  echo -n "${BLUE}Writing zero's to beginning of ${MAGENTA}/dev/$DEVICE${NORMAL} "
  dd if=/dev/zero of=/dev/$DEVICE bs=1k count=1 >/dev/null 2>&1 &
  rotdash $!
  echo " Done."
  sync
  echo "${BLUE}Partitioning ${MAGENTA}/dev/$DEVICE${NORMAL}"
  fdisk /dev/$DEVICE << EOF >/dev/null 2>&1
n
p
1


a
1
t
6
w
EOF
  sync
  hdparm -z /dev/$DEVICE
  echo "${BLUE}Formatting ${MAGENTA}/dev/$TARGET${NORMAL}"
  ./mkdosfs /dev/$TARGET >/dev/null 2>&1
  sync
  dd if=mbr.bin of=/dev/$DEVICE
  sync
fi  # End of installation options

echo "${BLUE}Applying syslinux to pendrive partition.${NORMAL}"
./syslinux /dev/$TARGET

mkdir boot
mount bootfloppy-usb.img boot -t vfat -o loop

echo "${BLUE}Setting up boot image on ${MAGENTA}/mnt/$TARGET${NORMAL}"
mkdir /mnt/pendrive
mount -t vfat /dev/$TARGET /mnt/pendrive
if [ $? != 0 ]; then
   echo "Error mounting usb device"
   echo -n "Press Enter key to continue."; read gagme
   exit 1
fi
cp  boot/* /mnt/pendrive
echo -n "${BLUE}Setting up system image on ${MAGENTA}/mnt/$TARGET${NORMAL}..."
cp -r $IMAGE/KNOPPIX /mnt/pendrive &
rotdash $!
sync
# $MYDSL is no longer needed because mydsl files are now stored in the
# root partition of the USB device. If $MYDSL is included in the boot command,
# duplicate Optional Fluxbox menus will be created by mistake.
sed -i s"/frugal/frugal $RESTORE $DAEMONS $LANG/" /mnt/pendrive/syslinux.cfg
sync
echo " Done."
umount boot /mnt/pendrive
echo "${GREEN}USB installation has completed${NORMAL}"
echo -n "Press Enter key to continue."; read gagme
